@@ -84,16 +84,33 @@ class snowflake_processor:
 
         """
         
+        # try:
+        #     engine = create_engine(
+        #         URL(
+        #             account = self.credentials.get('account'),
+        #             user = self.credentials.get('username'),
+        #             password = self.credentials.get('password'),
+        #             database = self.credentials.get('database'),
+        #             warehouse = self.credentials.get('warehouse'),
+        #         )
+        #     )
+        #     self.logger.info(f'Connection to {self.credentials.get("account")} successful')
+        # except:
+        #     self.logger.error('Exception occured', exc_info=True)
+        # else:
+        #     return engine
+
         try:
             engine = create_engine(
-                URL(
-                    account = self.credentials.get('account'),
+                "snowflake://{user}:{password}@{account_identifier}/".format(
                     user = self.credentials.get('username'),
                     password = self.credentials.get('password'),
-                    database = self.credentials.get('database'),
-                    warehouse = self.credentials.get('warehouse'),
+                    account = self.credentials.get('account'),
+                    db = self.credentials.get('database'),
+                    warehouse = self.credentials.get('warehouse')
+                    )
                 )
-            )
+
             self.logger.info(f'Connection to {self.credentials.get("account")} successful')
         except:
             self.logger.error('Exception occured', exc_info=True)
